using System;
using System.Collections.Generic;
//using System.Linq;
using System.Text;

namespace MTK
{
    public enum Levels {Low, High};
    public interface ISimI2CCtrl
    {
        Levels SDA { get; set; }
        Levels SCL { get; set; }

        bool I2C_Start();
        void I2C_Stop();
        byte I2C_RecvByte(bool IsAck);
        bool I2C_SendByte(byte data);

        bool WriteData(Byte slvAddr, Byte[] arr);
        byte ReadData(Byte slvAddr, Byte[] arr);

        bool WriteData(Byte[] data);
        bool ReadData(Byte[] data, byte[] wrCmds = null);
        bool Init();
    } 
}
